import os
import shutil

def before_flow_dir(isTrain=True, label_list=['train_label1','train_label2'], TARGET_DIR='/path/to/train', separator='.', label_position=0):
    """ 
    before_dir_flow: setup data from train/test directory to directory format corresponding to "ImageDataGenerator"
    method "flow_from_directory"
    
    <bool:isTrain> : defalut = True: to specify that we process the data for training
    <list:label_list>: to specify label (dir name) for training class
    <str:TARGET_DIR>: to specify main directory that your current dataset originally stored. Then it will 
    create a new sub-directory to represent label 
    <str:separator>: is set to get filename apart from its extensions
    <int:label_position>: is set to get filename apart from its extensions
    """
    if isTrain:
        for label in label_list:
            os.mkdir(os.path.join(TARGET_DIR,label))

        for img_fn in os.listdir(TARGET_DIR):
            class_name = img_fn.split(separator)[label_position]
            for i in range(len(label_list)):
                if class_name == label_list[i]:
                    shutil.move(os.path.join(TARGET_DIR,img_fn), os.path.join(TARGET_DIR,label_list[i]))
            else:
                pass
    else:
        test_destination = os.path.join(TARGET_DIR,'../test_tmp')
        os.mkdir(test_destination)
        shutil.move(TARGET_DIR, test_destination)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="elstargo", # Replace with your own username
    version="0.0.7",
    author="Elstargo",
    author_email="tagam2707@gmail.com",
    description="FOR THE GREATER GOOD",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Elstargo00/elstargo_package.git",
    packages=setuptools.find_packages(include=['elstargo','datamanagement']),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_required = [],
    setup_requires = ['pytest-runner'],
    tests_require = ['pytest==4.4.1'],
    test_suite='tests',
)
